# Twitter Developer Account Setup

To properly authenticate and use the Twitter API you will have to create a
developer application. Then, you can generate a client ID and client secret to
use with this project.

1. Create a Twitter developer account here: [Twitter Developer
   Portal](https://developer.twitter.com/en/portal/dashboard)
2. Create an project and application.
   >Use `http://localhost:8080` as the 'Callback URI / Redirect URL'
   >Use `http://github.com/jarulsamy/Twitter-Archive` as the Website URL
3. Generate an OAuth 2.0 client ID and client secret by following this
   documentation: [Twitter API Key and Secret
   Docs](https://developer.twitter.com/en/docs/authentication/oauth-1-0a/api-key-and-secret)
4. Save your tokens to use with this application.
5. Ensure your 'User authentication settings' look something like this:

    ![](/docs/assets/app_permissions.png)

    ![](/docs/assets/app_info.png)

    ![](/docs/assets/type_of_app.png)
